@@ -4,6 +4,7 @@ import json
 
 from iam_builder.iam_builder import build_iam_policy
 
+
 def main():
     parser = argparse.ArgumentParser()
     parser.add_argument("-c", "--config", help="path to your yaml/json config")
@@ -14,16 +15,17 @@ def main():
     output_path = args.output
 
     # Assume config is a yaml file if not json
-    with open(config_path, 'r') as f:
-        if config_path.endswith('.json'):
+    with open(config_path, "r") as f:
+        if config_path.endswith(".json"):
             config = json.load(f)
         else:
             config = yaml.load(f, Loader=yaml.FullLoader)
-    
+
     iam = build_iam_policy(config)
 
     with open(output_path, "w+") as outfile:
-        json.dump(iam, outfile, indent=4, separators=(',', ': '))
+        json.dump(iam, outfile, indent=4, separators=(",", ": "))
+
 
 if __name__ == "__main__":
     main()
